##  [](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/webhooks/paths/~1webhooks~1{id}/delete)Delete a webhook
**Access policy** : authenticated
##### Authorizations:
_ApiKeyAuth_ _jwt_
##### path Parameters
idrequired |  integer Webhook id
---|---
### Responses
**202**
Webhook deleted
**400**
Bad Request
**500**
Internal Server Error
delete/webhooks/{id}
https://api-docs.portainer.io/api/webhooks/{id}
